@@ -6,6 +6,10 @@
 Providers which implement the |openid|_ protocol based on the
 `python-openid`_ library.
 
+.. warning::
+    
+    This providers are dependent on the |pyopenid|_ package.
+    
 .. autosummary::
     
     OpenID
@@ -14,7 +18,7 @@ Providers which implement the |openid|_ protocol based on the
 
 """
 
-# We need absolute iport to import from openid library which has the same name as this module
+# We need absolute import to import from openid library which has the same name as this module
 from __future__ import absolute_import
 import datetime
 import logging
@@ -25,7 +29,6 @@ from openid.consumer import consumer
 from openid.extensions import ax, pape, sreg
 from openid.association import Association
 
-import authomatic.settings as settings
 from authomatic import providers
 from authomatic.exceptions import FailureError, CancellationError, OpenIDError
 
@@ -33,7 +36,7 @@ from authomatic.exceptions import FailureError, CancellationError, OpenIDError
 __all__ = ['OpenID', 'Yahoo', 'Google']
 
 
-# Supress openid logging.
+# Suppress openid logging.
 oidutil.log = lambda message, level=0: None
 
 
@@ -83,15 +86,15 @@ class SessionOpenIDStore(object):
         """
         :param int nonce_timeout:
             Nonces older than this in seconds will be considered expired.
-            Default is :data:`.settings.session_max_age`.
+            Default is 600.
         """
         
         self.session = session
-        self.nonce_timeout = nonce_timeout or settings.session_max_age
+        self.nonce_timeout = nonce_timeout or 600
     
     def storeAssociation(self, server_url, association):
         self._log(logging.DEBUG, 'SessionOpenIDStore: Storing association to session.')
-        # Allways store only one association as a tuple.
+        # Always store only one association as a tuple.
         self.session['oia'] = (server_url, association.handle, association.serialize())
     
     
@@ -225,7 +228,7 @@ class OpenID(providers.AuthenticationProvider):
         # AX
         self.ax = self._kwarg(kwargs, 'ax', self.AX)
         self.ax_required = self._kwarg(kwargs, 'ax_required', self.AX_REQUIRED)
-        # add required schemas to schemas if not allready there
+        # add required schemas to schemas if not already there
         for i in self.ax_required:
             if i not in self.ax:
                 self.ax.append(i)
@@ -319,7 +322,7 @@ class OpenID(providers.AuthenticationProvider):
                 
                 # get user ID
                 data['guid'] = response.getDisplayIdentifier()
-                
+
                 self._log(logging.INFO, 'Authentication successful.')
                 
                 # get user data from AX response
@@ -327,7 +330,7 @@ class OpenID(providers.AuthenticationProvider):
                 if ax_response and ax_response.data:
                     self._log(logging.INFO, 'Got AX data.')
                     ax_data = {}
-                    # conver iterable values to their first item
+                    # convert iterable values to their first item
                     for k, v in ax_response.data.iteritems():
                         if v and type(v) in (list, tuple):
                             ax_data[k] = v[0]
@@ -355,12 +358,12 @@ class OpenID(providers.AuthenticationProvider):
                 #===============================================================
             
             elif response.status == consumer.CANCEL:
-                raise CancellationError('User cancelled the verification of ID "{}"!'.format(response.getDisplayIdentifier()))
+                raise CancellationError('User cancelled the verification of ID "{0}"!'.format(response.getDisplayIdentifier()))
             
             elif response.status == consumer.FAILURE:
                 raise FailureError(response.message)
             
-        elif self.params.get(self.identifier_param):
+        elif self.identifier:  # As set in AuthenticationProvider.__init__
             #===================================================================
             # Phase 1 before redirect
             #===================================================================
@@ -371,11 +374,11 @@ class OpenID(providers.AuthenticationProvider):
             try:
                 auth_request = oi_consumer.begin(self.identifier)
             except consumer.DiscoveryFailure as e:
-                raise FailureError('Discovery failed for identifier {}!'.format(self.identifier),
+                raise FailureError('Discovery failed for identifier {0}!'.format(self.identifier),
                                    url=self.identifier,
                                    original_message=e.message)
             
-            self._log(logging.INFO, 'Service discovery for identifier {} successfull.'.format(self.identifier))
+            self._log(logging.INFO, 'Service discovery for identifier {0} successful.'.format(self.identifier))
             
             # add SREG extension
             # we need to remove required fields from optional fields because addExtension then raises an error
@@ -405,7 +408,7 @@ class OpenID(providers.AuthenticationProvider):
             if auth_request.shouldSendRedirect():
                 # can be redirected
                 url = auth_request.redirectURL(realm, return_to)
-                self._log(logging.INFO, 'Redirecting user to {}.'.format(url))
+                self._log(logging.INFO, 'Redirecting user to {0}.'.format(url))
                 self.redirect(url)
             else:
                 # must be sent as POST
